@@ -7,6 +7,7 @@ from openpyxl_image_loader import SheetImageLoader
 
 from domain.distribution.distribution_cell_value_types import DistributionCellValueType
 from domain.distribution.distribution_data import DistributionData
+from domain.distribution.distribution_image import DistributionImage
 from xlsx_lib.domain.xlsx_elements.exceptions.continue_exception import ContinueException
 from xlsx_lib.domain.xlsx_elements.exceptions.sheet_end_exception import SheetEndException
 from xlsx_lib.domain.xlsx_elements.sheet import Sheet
@@ -20,7 +21,7 @@ def get_distribution_value_type(cell: Cell) -> DistributionCellValueType:
 
 
 class DistributionSheet(Sheet):
-    distribution_images: List[BytesIO] = []
+    distribution_images: List[DistributionImage] = []
     max_col: int = 3
     start_col: int
 
@@ -41,8 +42,17 @@ class DistributionSheet(Sheet):
 
         image_loader = SheetImageLoader(worksheet)
 
+        image_index: int = 0
         for image in worksheet.images:
-            self.distribution_images.append(image.ref)
+            image_index += 1
+
+            self.distribution_images.append(
+                DistributionImage(
+                    name=str(image_index),
+                    format=image.format,
+                    file=image.ref,
+                )
+            )
 
         self.process_sheet_data()
 
