@@ -6,6 +6,7 @@ from openpyxl import \
     load_workbook
 
 from domain.distribution.distribution_data import DistributionData
+from domain.distribution.distribution_image import DistributionImage
 from domain.distribution.distribution_sheet import DistributionSheet
 from xlsx_lib.domain.power_supply.power_supply_component import PowerSupplyComponent
 from xlsx_lib.domain.power_supply.power_supply_sheet import PowerSupplySheet
@@ -39,7 +40,7 @@ sheetnames_relationships = {
 
 class MotorcycleModelWorkbook:
     motorcycle_model: Optional[MotorcycleModel]
-    distribution_sheet_images: Optional[List[BytesIO]]
+    distribution_sheet_images: Optional[List[DistributionImage]]
 
     def __init__(
             self,
